@@ -1,7 +1,7 @@
 # ABSTRACT: Utilities for Monitoring ElasticSearch
 package App::ElasticSearch::Utilities;
 
-our $VERSION = '4.5'; # VERSION
+our $VERSION = '4.6'; # VERSION
 
 use strict;
 use warnings;
@@ -462,7 +462,7 @@ sub es_index_bases {
 }
 
 
-my $NOW = timelocal(0,0,0,(localtime)[3,4,5]);
+my $NOW = timegm(0,0,0,(gmtime)[3,4,5]);
 sub es_index_days_old {
     my ($index) = @_;
 
@@ -479,8 +479,10 @@ sub es_index_days_old {
             }
         }
         $date[1]--; # move 1-12 -> 0-11
-        my $idx_time = timelocal( 0,0,0, @date );
+        my $idx_time = timegm( 0,0,0, @date );
         my $diff = $NOW - $idx_time;
+        $diff++;    # Add one second
+        debug({color=>"yellow"}, sprintf "es_index_days_old(%s) - Time difference is %0.3f", $index, $diff/86400);
         return int($diff / 86400);
     }
     return;
@@ -698,7 +700,7 @@ App::ElasticSearch::Utilities - Utilities for Monitoring ElasticSearch
 
 =head1 VERSION
 
-version 4.5
+version 4.6
 
 =head1 SYNOPSIS
 
